@@ -17,12 +17,12 @@ declareConsts = function() {
 }
 
 logLik = function( params, data ) {
-    baseDist = tf$contrib$distributions$Normal( params$theta, 1 )
+    baseDist = tf$distributions$Normal( params$theta, 1 )
     return( tf$reduce_sum( baseDist$log_prob( data$X ) ) )
 }
 
 logPrior = function( params ) {
-    baseDist = tf$contrib$distributions$Normal( 0, 5 )
+    baseDist = tf$distributions$Normal( 0, 5 )
     return( tf$reduce_sum( baseDist$log_prob( params$theta ) ) )
 }
 
